/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config;

import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.Value;
import org.eclipse.sapphire.ValueProperty;
import org.eclipse.sapphire.modeling.annotations.Documentation;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.PossibleValues;
import org.eclipse.sapphire.modeling.annotations.Required;
import org.eclipse.sapphire.modeling.xml.annotations.XmlBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "run-as role" )

@Documentation
(
    content = "Specifies the security role to be used for the execution of a component."
)

public interface RunAsSecurityRole extends Describable
{
    ElementType TYPE = new ElementType( RunAsSecurityRole.class );

    // *** Role ***
    
    @Label( standard = "role" )
    @Required
    @PossibleValues( property = "/SecurityRoles/Name" )
    @XmlBinding( path = "role-name" )
    
    ValueProperty PROP_ROLE = new ValueProperty( TYPE, "Role" );
    
    Value<String> getRole();
    void setRole( String value );
    
}
