/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.environment;

import org.eclipse.jst.config.Describable;
import org.eclipse.sapphire.ElementList;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.ListProperty;
import org.eclipse.sapphire.Since;
import org.eclipse.sapphire.Value;
import org.eclipse.sapphire.ValueProperty;
import org.eclipse.sapphire.modeling.annotations.Documentation;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.NoDuplicates;
import org.eclipse.sapphire.modeling.annotations.Required;
import org.eclipse.sapphire.modeling.annotations.Type;
import org.eclipse.sapphire.modeling.xml.annotations.XmlBinding;
import org.eclipse.sapphire.modeling.xml.annotations.XmlListBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "environment reference" )

public interface EnvironmentRef extends Describable
{
    ElementType TYPE = new ElementType( EnvironmentRef.class );
    
    // *** Name ***
    
    @Label( standard = "name" )
    @Required
    @NoDuplicates

    ValueProperty PROP_NAME = new ValueProperty( TYPE, "Name" );
    
    Value<String> getName();
    void setName( String value );
    
    // *** MappedName ***
    
    @Label( standard = "mapped name" )
    @Since( "2.5" )
    @XmlBinding( path = "mapped-name" )
    
    @Documentation
    (
        content = "A product specific name that this resource should be mapped to. The name of this resource, " +
                  "as defined by the resource's name element or defaulted, is a name that is local to the application " +
                  "component using the resource. It's a name in the JNDI java:comp/env namespace.  Many application " +
                  "servers provide a way to map these local names to names of resources known to the application " +
                  "server. This mapped name is often a global JNDI name, but may be a name of any form." +
                  "[pbr/]" +
                  "Application servers are not required to support any particular form or type of mapped name, nor " +
                  "the ability to use mapped names. The mapped name is product-dependent and often installation-dependent. " +
                  "No use of a mapped name is portable."
    )
    
    ValueProperty PROP_MAPPED_NAME = new ValueProperty( TYPE, "MappedName" );
    
    Value<String> getMappedName();
    void setMappedName( String value );
    
    // *** InjectionTargets ***
    
    @Type( base = InjectionTarget.class )
    @Label( standard = "injection targets" )
    @XmlListBinding( path = "" )
    @Since( "2.5" )
    
    @Documentation
    (
        content = "Resources can be injected directly into objects where they are needed."+
                  "[pbr/]" +
                  "The types of classes that can receive " +
                  "injections and when the injection occurrs in the component's lifecycle is specified by the individual " +
                  "Java EE component specifications. Typically injection will occurr after an instance of the class is " +
                  "constructed, but before any business methods are called. If the server fails to find a resource " +
                  "needed for injection, initialization of the object will fail and the object will not be put into service." +
                  "[pbr/]" +
                  "Injection target can be a JavaBeans property or a field. The bean setter method or the field may have " +
                  "any access qualifier, including private. The field may not be final and should not be static (except " +
                  "for the main class of an application client)." +
                  "[pbr/]" +
                  "Types of classes supporting injection:" +
                  "[ul]" +
                  "[li]Servlet[/li]" +
                  "[li]Servlet filter[/li]" +
                  "[li]Servlet event listener[/li]" +
                  "[li]JSP tag handler[/li]" +
                  "[li]JSP tag library event listener[/li]" +
                  "[li]JSF scoped managed bean[/li]" +
                  "[li]JAX-WS service endpoint[/li]" +
                  "[li]JAX-WS handler[/li]" +
                  "[li]EJB bean[/li]" +
                  "[li]EJB interceptor[/li]" +
                  "[li]Main class of an application client[/li]" +
                  "[li]Login callback handler[/li]" +
                  "[/ul]"
    )
    
    ListProperty PROP_INJECTION_TARGETS = new ListProperty( TYPE, "InjectionTargets" );
    
    ElementList<InjectionTarget> getInjectionTargets();
    
}
