/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.environment;

import org.eclipse.sapphire.java.JavaIdentifier;
import org.eclipse.sapphire.java.JavaType;
import org.eclipse.sapphire.java.JavaTypeConstraint;
import org.eclipse.sapphire.java.JavaTypeKind;
import org.eclipse.sapphire.java.JavaTypeName;
import org.eclipse.sapphire.Element;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.ReferenceValue;
import org.eclipse.sapphire.Value;
import org.eclipse.sapphire.ValueProperty;
import org.eclipse.sapphire.modeling.annotations.Documentation;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.MustExist;
import org.eclipse.sapphire.modeling.annotations.Reference;
import org.eclipse.sapphire.modeling.annotations.Required;
import org.eclipse.sapphire.modeling.annotations.Type;
import org.eclipse.sapphire.modeling.xml.annotations.XmlBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "injection target" )
@XmlBinding( path = "injection-target" )

public interface InjectionTarget extends Element
{
    ElementType TYPE = new ElementType( InjectionTarget.class );
    
    // *** TargetClass ***
    
    @Type( base = JavaTypeName.class )
    @Reference( target = JavaType.class )
    @Label( standard = "class" )
    @Required
    @MustExist
    @JavaTypeConstraint( kind = JavaTypeKind.CLASS )
    @XmlBinding( path = "injection-target-class" )
    
    @Documentation
    (
        content = "The class that is the target of the injection. The Java EE specifications " +
                  "describe which classes can be an injection target."
    )
    
    ValueProperty PROP_TARGET_CLASS = new ValueProperty( TYPE, "TargetClass" );
    
    ReferenceValue<JavaTypeName,JavaType> getTargetClass();
    void setTargetClass( String value );
    void setTargetClass( JavaTypeName value );
    
    // *** TargetProperty ***
    
    @Type( base = JavaIdentifier.class )
    @Label( standard = "property" )
    @Required
    @XmlBinding( path = "injection-target-name" )
    
    @Documentation
    (
        content = "The name of a JavaBeans property or a field. The bean setter method or the field may have " +
                  "any access qualifier, including private. The field may not be final and should not be static (except " +
                  "for the main class of an application client)."
    )
    
    ValueProperty PROP_TARGET_PROPERTY = new ValueProperty( TYPE, "TargetProperty" );
    
    Value<JavaIdentifier> getTargetProperty();
    void setTargetProperty( String value );
    void setTargetProperty( JavaIdentifier value );
    
}
