/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.environment;

import org.eclipse.jst.config.DescribableExt;
import org.eclipse.sapphire.Since;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.Value;
import org.eclipse.sapphire.ValueProperty;
import org.eclipse.sapphire.modeling.annotations.Documentation;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.NoDuplicates;
import org.eclipse.sapphire.modeling.annotations.Required;
import org.eclipse.sapphire.modeling.xml.annotations.XmlBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "message destination" )

public interface MessageDestination extends DescribableExt
{
    ElementType TYPE = new ElementType( MessageDestination.class );
    
    // *** Name ***

    @Label( standard = "name" )
    @Required
    @NoDuplicates
    @XmlBinding( path = "message-destination-name" )
    
    @Documentation
    (
        content = "The name of a message destination. The name must be unique within this deployment " +
                  "component, but uniqueness across components on the same server is not required."
    )

    ValueProperty PROP_NAME = new ValueProperty( TYPE, "Name" );
    
    Value<String> getName();
    void setName( String value );
    
    // *** MappedName ***
    
    @Label( standard = "mapped name" )
    @Since( "2.5" )
    @XmlBinding( path = "mapped-name" )
    
    @Documentation
    (
        content = "A product specific name that this message destination should be mapped to. Each message destination " +
                  "reference will define a name in the namespace of the referencing component. It's a name in the JNDI " +
                  "java:comp/env namespace.  Many application servers provide a way to map these local names to names of " +
                  "resources known to the application server. This mapped name is often a global JNDI name, but may be a " +
                  "name of any form. Each of the local names should be mapped to this same global name." +
                  "[pbr/]" +
                  "Application servers are not required to support any particular form or type of mapped name, nor " +
                  "the ability to use mapped names. The mapped name is product-dependent and often installation-dependent. " +
                  "No use of a mapped name is portable."
    )
    
    ValueProperty PROP_MAPPED_NAME = new ValueProperty( TYPE, "MappedName" );
    
    Value<String> getMappedName();
    void setMappedName( String value );
    
}
