/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.environment.internal;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jst.config.EnterpriseJavaModuleConfig;
import org.eclipse.jst.config.environment.EjbLocalRef;
import org.eclipse.jst.config.environment.EjbRemoteRef;
import org.eclipse.jst.config.environment.EnvironmentEntry;
import org.eclipse.jst.config.environment.MessageDestinationRef;
import org.eclipse.jst.config.environment.ResourceEnvironmentRef;
import org.eclipse.jst.config.environment.ResourceRef;
import org.eclipse.jst.config.environment.ServiceRef;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.FilteredListener;
import org.eclipse.sapphire.Listener;
import org.eclipse.sapphire.PropertyContentEvent;
import org.eclipse.sapphire.Version;
import org.eclipse.sapphire.services.PossibleTypesService;
import org.eclipse.sapphire.services.PossibleTypesServiceData;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class EnvironmentConsumerServices
{
    public static final class EnvironmentRefsPossibleTypesService extends PossibleTypesService
    {
        private EnterpriseJavaModuleConfig config;
        private Listener listener;
        
        @Override
        protected void initPossibleTypesService()
        {
            this.listener = new FilteredListener<PropertyContentEvent>()
            {
                @Override
                protected void handleTypedEvent( final PropertyContentEvent event )
                {
                    refresh();
                }
            };
            
            this.config = context( EnterpriseJavaModuleConfig.class );
            this.config.getEnterpriseJavaPlatformVersion().attach( this.listener );
        }

        @Override
        protected PossibleTypesServiceData compute()
        {
            final Version version = new Version( context( EnterpriseJavaModuleConfig.class ).getEnterpriseJavaPlatformVersion().content().toString() );
            final List<ElementType> types = new ArrayList<ElementType>();
            
            types.add( EnvironmentEntry.TYPE );
            types.add( EjbRemoteRef.TYPE );
            types.add( ResourceRef.TYPE );
            
            if( version.matches( "[1.3" ) )
            {
                types.add( EjbLocalRef.TYPE );
                types.add( ResourceEnvironmentRef.TYPE );
            }
            
            if( version.matches( "[1.4" ) )
            {
                types.add( MessageDestinationRef.TYPE );
                types.add( ServiceRef.TYPE );
            }
            
            return new PossibleTypesServiceData( types );
        }

        @Override
        public void dispose()
        {
            super.dispose();
            
            if( this.listener != null && ! this.config.disposed() )
            {
                this.config.getEnterpriseJavaPlatformVersion().detach( this.listener );
                
                this.config = null;
                this.listener = null;
            }
        }
    }
    
}
