/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.web;

import org.eclipse.jst.config.web.internal.TagLibrariesBinding;
import org.eclipse.sapphire.Since;
import org.eclipse.sapphire.Element;
import org.eclipse.sapphire.ListProperty;
import org.eclipse.sapphire.ElementList;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.modeling.annotations.Documentation;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.Type;
import org.eclipse.sapphire.modeling.xml.annotations.CustomXmlListBinding;
import org.eclipse.sapphire.modeling.xml.annotations.XmlListBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "JSP configuration" )

public interface JspConfig extends Element
{
    ElementType TYPE = new ElementType( JspConfig.class );
    
    // *** TagLibraries ***
    
    @Type( base = TagLibrary.class )
    @Label( standard = "tag libraries" )
    @CustomXmlListBinding( impl = TagLibrariesBinding.class )
    
    @Documentation
    (
        content = "Tag library definitions specify the tag libraries available to the web application. This can " +
                  "be done to override implicit map entries from TLD files and from the container."
    )
    
    ListProperty PROP_TAG_LIBRARIES = new ListProperty( TYPE, "TagLibraries" );
    
    ElementList<TagLibrary> getTagLibraries();
    
    // *** PropertyGroups ***
    
    @Type( base = JspPropertyGroup.class )
    @Label( standard = "property groups" )
    @Since( "2.4" )
    @XmlListBinding( path = "jsp-config", mappings = @XmlListBinding.Mapping( element = "jsp-property-group", type = JspPropertyGroup.class ) )
    
    @Documentation
    (
        content = "Property groups provide global configuration that should be applied to the specified sets of " +
                  "web application resources. All resources so described are deemed to be JSP files."
    )
    
    ListProperty PROP_PROPERTY_GROUPS = new ListProperty( TYPE, "PropertyGroups" );
    
    ElementList<JspPropertyGroup> getPropertyGroups();
    
}
