/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.web;

import org.eclipse.jst.config.Describable;
import org.eclipse.jst.config.DescribableExt;
import org.eclipse.sapphire.Since;
import org.eclipse.sapphire.java.JavaType;
import org.eclipse.sapphire.java.JavaTypeConstraint;
import org.eclipse.sapphire.java.JavaTypeKind;
import org.eclipse.sapphire.java.JavaTypeName;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.ReferenceValue;
import org.eclipse.sapphire.ValueProperty;
import org.eclipse.sapphire.modeling.annotations.Documentation;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.MustExist;
import org.eclipse.sapphire.modeling.annotations.Reference;
import org.eclipse.sapphire.modeling.annotations.Required;
import org.eclipse.sapphire.modeling.annotations.Type;
import org.eclipse.sapphire.modeling.xml.annotations.XmlBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public interface Listener extends DescribableExt
{
    ElementType TYPE = new ElementType( Listener.class );
    
    // *** Implementation ***
    
    @Type( base = JavaTypeName.class )
    @Reference( target = JavaType.class )
    @Label( standard = "implementation class", full = "listener implementation class" )
    @Required
    @MustExist
    @JavaTypeConstraint( kind = JavaTypeKind.CLASS, type = "javax.servlet.ServletContextListener" ) // TODO: or javax.servlet.http.HttpSessionListener
    @XmlBinding( path = "listener-class" )
    
    @Documentation
    (
        content = "The listener implementation class."
    )
    
    ValueProperty PROP_IMPLEMENTATION = new ValueProperty( TYPE, "Implementation" );
    
    ReferenceValue<JavaTypeName,JavaType> getImplementation();
    void setImplementation( String value );
    void setImplementation( JavaTypeName value );
    
    // *** DisplayName ***
    
    @Since( "2.4" )
    
    ValueProperty PROP_DISPLAY_NAME = new ValueProperty( TYPE, DescribableExt.PROP_DISPLAY_NAME );
    
    // *** Description ***
    
    @Since( "2.4" )
    
    ValueProperty PROP_DESCRIPTION = new ValueProperty( TYPE, Describable.PROP_DESCRIPTION );
    
    // *** SmallIcon ***
    
    @Since( "2.4" )
    
    ValueProperty PROP_SMALL_ICON = new ValueProperty( TYPE, DescribableExt.PROP_SMALL_ICON );
    
    // *** LargeIcon ***
    
    @Since( "2.4" )
    
    ValueProperty PROP_LARGE_ICON = new ValueProperty( TYPE, DescribableExt.PROP_LARGE_ICON );
    
}
