/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.web;

import org.eclipse.jst.config.web.internal.LocaleEncodingMappingServices;
import org.eclipse.sapphire.Element;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.Value;
import org.eclipse.sapphire.ValueProperty;
import org.eclipse.sapphire.modeling.annotations.Documentation;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.Required;
import org.eclipse.sapphire.modeling.annotations.Service;
import org.eclipse.sapphire.modeling.xml.annotations.XmlBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "locale encoding mapping" )

@Documentation
(
    content = "Locale encoding mappings tell the container how to set the character encoding when a servlet " +
              "specifies a particular locale in the ServletResponse.setLocale() call. If the web application " +
              "does not specify a locale encoding mapping, the mapping is container dependent"
)

public interface LocaleEncodingMapping extends Element
{
    ElementType TYPE = new ElementType( LocaleEncodingMapping.class );
    
    // *** Locale ***
    
    @Label( standard = "locale" )
    @Required
    @Service( impl = LocaleEncodingMappingServices.LocalePossibleValuesService.class )
    @XmlBinding( path = "locale" )
    
    @Documentation
    (
        content = "Locale is either a language code as defined by ISO-639-1 or a language code " +
                  "followed by a country code as defined by ISO-3166." +
                  "[pbr/]" +
                  "Examples: ja, ja_JP"
    )
    
    // Pattern: [a-z]{2}(_|-)?([\p{L}\-\p{Nd}]{2})?
    
    ValueProperty PROP_LOCALE = new ValueProperty( TYPE, "Locale" );
    
    Value<String> getLocale();
    void setLocale( String value );
    
    // *** Encoding ***
    
    @Label( standard = "encoding" )
    @Required
    @XmlBinding( path = "encoding" )
    
    // Pattern: [^\s]+
    
    ValueProperty PROP_ENCODING = new ValueProperty( TYPE, "Encoding" );
    
    Value<String> getEncoding();
    void setEncoding( String value );

}
