/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.web;

import org.eclipse.jst.config.EnterpriseJavaPlatformVersion;
import org.eclipse.sapphire.modeling.annotations.EnumSerialization;
import org.eclipse.sapphire.modeling.annotations.Label;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "servlet platform version" )

public enum ServletPlatformVersion
{
    @Label( standard = "3.0" )
    @EnumSerialization( primary = "3.0" )
    
    VERSION_3_0( "3.0", EnterpriseJavaPlatformVersion.VERSION_6 ),
    
    @Label( standard = "2.5" )
    @EnumSerialization( primary = "2.5" )
    
    VERSION_2_5( "2.5", EnterpriseJavaPlatformVersion.VERSION_5 ),
    
    @Label( standard = "2.4" )
    @EnumSerialization( primary = "2.4" )
    
    VERSION_2_4( "2.4", EnterpriseJavaPlatformVersion.VERSION_1_4 ),
    
    @Label( standard = "2.3" )
    @EnumSerialization( primary = "2.3" )
    
    VERSION_2_3( "2.3", EnterpriseJavaPlatformVersion.VERSION_1_3 ),
    
    @Label( standard = "2.2" )
    @EnumSerialization( primary = "2.2" )
    
    VERSION_2_2( "2.2", EnterpriseJavaPlatformVersion.VERSION_1_2 );
    
    public static ServletPlatformVersion parse( final String string )
    {
        if( string != null )
        {
            for( ServletPlatformVersion version : ServletPlatformVersion.values() )
            {
                if( string.equals( version.toString() ) )
                {
                    return version;
                }
            }
        }
        
        return null;
    }
    
    private final String version;
    private final EnterpriseJavaPlatformVersion enterpriseJavaPlatformVersion;
    
    private ServletPlatformVersion( final String version, 
                                    final EnterpriseJavaPlatformVersion enterpriseJavaPlatformVersion )
    {
        this.version = version;
        this.enterpriseJavaPlatformVersion = enterpriseJavaPlatformVersion;
    }
    
    public EnterpriseJavaPlatformVersion toEnterpriseJavaPlatformVersion()
    {
        return this.enterpriseJavaPlatformVersion;
    }
    
    @Override
    public String toString()
    {
        return this.version;
    }

}
