/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.web.internal;

import org.eclipse.jst.config.EnterpriseJavaPlatformVersion;
import org.eclipse.jst.config.web.ServletPlatformVersion;
import org.eclipse.jst.config.web.WebAppConfig;
import org.eclipse.sapphire.ValuePropertyBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class EnterpriseJavaPlatformVersionBinding extends ValuePropertyBinding
{
    @Override
    public String read()
    {
        final String servletPlatformVersionText = ( (WebAppConfig) property().element() ).getServletPlatformVersion().text();
        final ServletPlatformVersion servletPlatformVersion = ServletPlatformVersion.parse( servletPlatformVersionText );
        
        String enterpriseJavaPlatformVersionText;
        
        if( servletPlatformVersion == null )
        {
            enterpriseJavaPlatformVersionText = servletPlatformVersionText;
        }
        else
        {
            enterpriseJavaPlatformVersionText = servletPlatformVersion.toEnterpriseJavaPlatformVersion().toString();
        }
        
        return enterpriseJavaPlatformVersionText;
    }

    @Override
    public void write( final String value )
    {
        final EnterpriseJavaPlatformVersion enterpriseJavaPlatformVersion = EnterpriseJavaPlatformVersion.parse( value );
        
        String servletPlatformVersionText = null;
        
        if( enterpriseJavaPlatformVersion == null )
        {
            servletPlatformVersionText = value;
        }
        else
        {
            for( ServletPlatformVersion servletPlatformVersion : ServletPlatformVersion.values() )
            {
                if( servletPlatformVersion.toEnterpriseJavaPlatformVersion() == enterpriseJavaPlatformVersion )
                {
                    servletPlatformVersionText = servletPlatformVersion.toString();
                    break;
                }
            }
        }
        
        ( (WebAppConfig) property().element() ).setServletPlatformVersion( servletPlatformVersionText );
    }
    
}
