/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.web.internal;

import javax.xml.namespace.QName;

import org.eclipse.jst.config.web.TagLibrary;
import org.eclipse.jst.config.web.WebAppConfig;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.Version;
import org.eclipse.sapphire.modeling.xml.StandardXmlListBindingImpl;
import org.eclipse.sapphire.modeling.xml.XmlElement;
import org.eclipse.sapphire.modeling.xml.XmlPath;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class TagLibrariesBinding extends StandardXmlListBindingImpl
{
    private static final String EL_JSP_CONFIG = "jsp-config";
    private static final String EL_TAGLIB = "taglib";
    
    @Override
    protected void initBindingMetadata()
    {
        this.modelElementTypes = new ElementType[] { TagLibrary.TYPE };
        this.xmlElementNames = new QName[] { new QName( EL_TAGLIB ) };
    }
    
    @Override
    protected XmlElement getXmlElement( final boolean createIfNecessary )
    {
        final Version version = new Version( property().nearest( WebAppConfig.class ).getEnterpriseJavaPlatformVersion().content().toString() );
        
        XmlElement parent = getBaseXmlElement( createIfNecessary );
        
        if( parent != null && version.matches( "[1.4" ) )
        {
            parent = (XmlElement) parent.getChildNode( new XmlPath( EL_JSP_CONFIG ), createIfNecessary );
        }
        
        return parent;
    }
    
}
