/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.web.internal;

import java.util.Set;

import org.eclipse.jst.config.web.WebAppConfig;
import org.eclipse.sapphire.FilteredListener;
import org.eclipse.sapphire.Listener;
import org.eclipse.sapphire.PropertyContentEvent;
import org.eclipse.sapphire.Version;
import org.eclipse.sapphire.modeling.Status;
import org.eclipse.sapphire.modeling.Status.Severity;
import org.eclipse.sapphire.services.PossibleValuesService;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class WebResourceCollectionServices
{
    public static final class HttpMethodPossibleValuesService extends PossibleValuesService
    {
        private static final String GET = "GET";
        private static final String POST = "POST";
        private static final String PUT = "PUT";
        private static final String DELETE = "DELETE";
        private static final String HEAD = "HEAD";
        private static final String OPTIONS = "OPTIONS";
        private static final String TRACE = "TRACE";
        
        private WebAppConfig config;
        private Listener servletPlatformVersionListener;
        
        @Override
        protected void init()
        {
            super.init();
            
            this.config = context( WebAppConfig.class );
            
            if( this.config != null )
            {
                this.servletPlatformVersionListener = new FilteredListener<PropertyContentEvent>()
                {
                    @Override
                    protected void handleTypedEvent( final PropertyContentEvent event )
                    {
                        broadcast();
                    }
                };
                
                this.config.getServletPlatformVersion().attach( this.servletPlatformVersionListener );
            }
        }

        @Override
        protected void fillPossibleValues( final Set<String> values )
        {
            values.add( GET );
            values.add( POST );
            values.add( PUT );
            values.add( DELETE );
            values.add( HEAD );
            values.add( OPTIONS );
            values.add( TRACE );
        }

        @Override
        public Severity getInvalidValueSeverity( final String invalidValue )
        {
            if( this.config != null )
            {
                final Version version = new Version( this.config.getServletPlatformVersion().text() );
                
                if( version.matches( "2.4]" ) )
                {
                    return Status.Severity.ERROR;
                }
            }
            
            return Status.Severity.OK;
        }
        
        @Override
        public void dispose()
        {
            super.dispose();
            
            if( this.config != null && ! this.config.disposed() )
            {
                this.config.getServletPlatformVersion().detach( this.servletPlatformVersionListener );
            }
        }
    }
    
}
