/******************************************************************************
 * Copyright (c) 2013 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.jst.config.web.ui.internal;

import org.eclipse.sapphire.Element;
import org.eclipse.sapphire.ReferenceValue;
import org.eclipse.sapphire.ui.Presentation;
import org.eclipse.sapphire.ui.forms.JumpActionHandler;
import org.eclipse.sapphire.ui.forms.MasterDetailsContentNodePart;
import org.eclipse.sapphire.ui.forms.MasterDetailsEditorPagePart;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class ElementReferenceJumpActionHandler extends JumpActionHandler
{
    @Override
    protected boolean computeEnablementState()
    {
        if( super.computeEnablementState() == true )
        {
            return ( reference().resolve() != null );
        }
        
        return false;
    }

    @Override
    protected Object run( final Presentation context )
    {
        final ReferenceValue<String,Element> ref = reference();
        final Element element = ref.resolve();
        
        if( element != null )
        {
            final MasterDetailsEditorPagePart page = getPart().nearest( MasterDetailsEditorPagePart.class );
            final MasterDetailsContentNodePart root = page.outline().getRoot();
            final MasterDetailsContentNodePart node = root.findNode( element );
            
            if( node != null )
            {
                node.select();
            }
        }
        
        return null;
    }
    
    @SuppressWarnings( "unchecked" )
    private ReferenceValue<String,Element> reference()
    {
        return (ReferenceValue<String,Element>) property();
    }
    
}
